<?php 
/**
* @version 1.0
* @package: Module Facebook Like Box
* @author: Stavros Stratakis
* @email: info@webgift.gr
* @link: http://www.webgift.gr
* @license: http://creativecommons.org/licenses/by-sa/3.0/ Creative Commons 3.0 SA
* @copyright: (C) 2010-2011 Stavros Stratakis (WebGift Web services). All rights reserved.
* @description: Displays Facebook like Box. See http://developers.facebook.com/docs/reference/plugins/like-box/
*/

defined('_VALID_MOS') or die('Direct Access to this location is not allowed.');


if (!class_exists('modFacebookLikeBox', false)) {
	class modFacebookLikeBox {

		private $url = 'www.facebook.com/webgiftgr';
        private $fbml = 1;
		private $show_faces = 'true';
        private $show_stream = 'true';
        private $show_header = 'true';
		private $width = 300;
		private $height = 588;
		private $colorscheme = 0;
		private $locale = 'en_US';
        		

		/***************/
		/* CONSTRUCTOR */
		/***************/
		public function __construct($params) {
			$this->getConfig($params);
		}


		/********************************/
		/* GET CONFIGURATION PARAMETERS */
		/********************************/
		private function getConfig($params) {
			$this->fbml = (int)$params->get('fbml', 1);
			$this->url = (string)$params->get('url', 'www.facebook.com/webgiftgr');
			$this->show_faces = (intval($params->get('show_faces', 0) == 1)) ? 'true' : 'false';
            $this->show_stream = (intval($params->get('show_stream', 0) == 1)) ? 'true' : 'false';
            $this->show_header = (intval($params->get('show_header', 0) == 1)) ? 'true' : 'false';
			$this->width = (int)$params->get('width', 300);
			if ($this->width < 10) { $this->width = 300; }
			$this->height = (int)$params->get('height', 588);
			$this->colorscheme = (intval($params->get('colorscheme', 0) == 0 )) ? 'light' : 'dark';

			if ($this->fbml == 0) {
				$this->locale = (string)$params->get('locale', '');
				if ($this->locale == '') {
					global $lang;
					switch ($lang) {
						case 'english': $this->locale = 'en_US'; break;
						case 'greek': $this->locale = 'el_GR'; break;
						case 'german': $this->locale = 'de_DE'; break;
						case 'italian': $this->locale = 'it_IT'; break;
						case 'spanish': $this->locale = 'es_ES'; break;
						case 'french': $this->locale = 'fr_FR'; break;
						case 'russian': $this->locale = 'ru_RU'; break;
						case 'czech': $this->locale = 'cs_CZ'; break;
						case 'danish': $this->locale = 'da_DK'; break;
						case 'finnish': $this->locale = 'fi_FI'; break;
						case 'portuguese': $this->locale = 'pt_PT'; break;
						case 'hungarian': $this->locale = 'hu_HU'; break;
						case 'serbian': case 'srpski': $this->locale = 'sr_RS'; break;
						case 'japanese': $this->locale = 'ja_JP'; break;
						case 'korean': $this->locale = 'ko_KR'; break;
						case 'turkish': $this->locale = 'tr_TR'; break;
						case 'norwegian': $this->locale = 'nb_NO'; break;
						case 'dutch': $this->locale = 'nl_NL'; break;
						case 'polish': $this->locale = 'pl_PL'; break;
						case 'romanian': $this->locale = 'ro_RO'; break;
						case 'slovak': case 'slovakean': $this->locale = 'sk_SK'; break;
						case 'slovenian': $this->locale = 'sl_SI'; break;
						case 'swedish': $this->locale = 'sv_SE'; break;
						case 'chinese': case 'chinese_simplified': $this->locale = 'zh_CN'; break;
						case 'chinese_traditional': $this->locale = 'zh_HK'; break;
						case 'albanian': $this->locale = 'sq_AL'; break;
						case 'azeri': $this->locale = 'az_AZ'; break;
						case 'bosnian': $this->locale = 'bs_BA'; break;
						case 'bulgarian': $this->locale = 'bg_BG'; break;
						case 'croatian': $this->locale = 'hr_HR'; break;
						case 'estonian': $this->locale = 'et_EE'; break;
						case 'georgian': $this->locale = 'ka_GE'; break;
						case 'indonesian': $this->locale = 'id_ID'; break;
						case 'latvian': $this->locale = 'lv_LV'; break;
						case 'lithuanian': $this->locale = 'lt_LT'; break;
						case 'ukrainian': $this->locale = 'uk_UA'; break;
						case 'vietnamese': $this->locale = 'vi_VN'; break;
						case 'hebrew': $this->locale = 'he_IL'; break;
						case 'persian': $this->locale = 'fa_IR'; break;
						default: $this->locale = 'en_US'; break;
					}
				}
			}
		}


		/******************/
		/* EXECUTE MODULE */
		/******************/
		public function run() {
			$url = urlencode($this->url);
			if ($this->fbml == 1) {
				$this->showFBML($url);
			} else {
				$this->showiFrame($url);
			}
		}


		/*********************************/
		/* SHOW FB LIKE WITHIN AN IFRAME */
		/*********************************/
		private function showiFrame($url) {
			$iframesrc = 'http://www.facebook.com/plugins/likebox.php';
			if (isset($_SERVER['HTTPS'])) {
				if (($_SERVER['HTTPS'] == 'on') || ($_SERVER['HTTPS'] == 1)) {
					$iframesrc = 'https://www.facebook.com/plugins/likebox.php';
				}
			}
			$out = '<iframe src="'.$iframesrc.'?href='.$url.'&amp;locale='.$this->locale.'&amp;header='.$this->show_header.'&amp;show_faces='.$this->show_faces;
			$out .= '&amp;width='.$this->width.'&amp;stream='.$this->show_stream.'&amp;font=tahoma&amp;colorscheme='.$this->colorscheme;
			if ($this->height > 0) { $out .= '&amp;height='.$this->height; }
			$out .= '" scrolling="no" frameborder="0" allowTransparency="true"';
			$out .= ' style="border:none; overflow:hidden;  width:'.$this->width.'px;';
			if ($this->height > 0) {$out .= 'height:'.$this->height.'px;'; }
			$out .= '"></iframe>'."\n";
			$out .= '<div style="clear:both;"></div>'."\n";
			echo $out;

		}


		/**************************/
		/* SHOW FB LIKE WITH FBML */
		/**************************/
		private function showFBML($url) {
			$jsurl = 'http://connect.facebook.net';
			if (isset($_SERVER['HTTPS'])) {
				if (($_SERVER['HTTPS'] == 'on') || ($_SERVER['HTTPS'] == 1)) {
					$jsurl = 'https://connect.facebook.net';
				}
			}
			$out = '<script type="text/javascript" src="'.$jsurl.'/'.$this->locale.'/all.js#xfbml=1"></script>'."\n";
			$out .= '<fb:like-box href="'.$url.'" stream="'.$this->show_stream.'" show_faces="'.$this->show_faces.'"';
			$out .= ' width="'.$this->width.'" header="'.$this->show_header.'" font="tahoma" colorscheme="'.$this->colorscheme.'"></fb:like-box>'."\n";
			$out .= '<div style="clear:both;"></div>'."\n";
			echo $out;
		}

	}
}


$facebookLike = new modFacebookLikeBox($params);
$facebookLike->run();
unset($facebookLike);

?>